@@ -236,6 +236,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
+          is_expected.to contain_tempest_config('network/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
@@ -248,9 +249,11 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/bgpvpn').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/panko').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
+          is_expected.to contain_tempest_config('service_available/l2gw').with(:value => false)
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
           is_expected.to contain_tempest_config('service_available/mistral').with(:value => false)
           is_expected.to contain_tempest_config('service_available/vitrage').with(:value => false)
@@ -276,6 +279,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('scenario/img_dir').with(:value => '/var/lib/tempest')
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => 'cirros-0.3.4-x86_64-disk.img')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
+
+          is_expected.not_to contain_tempest_config('magnum/keypair_id').with_value('default')
         end
 
         it 'set glance id' do
@@ -401,6 +406,8 @@ describe 'tempest' do
         it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-lbaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
+        it { expect { is_expected.to contain_package('python-networking-bgpvpn-tests') } }
+        it { expect { is_expected.to contain_package('python-networking-l2gw-tests') } }
         it { expect { is_expected.to contain_package('python-horizon-tests-tempest') } }
       end
     end
